@@ -2,7 +2,7 @@
 use 5.008001; use utf8; use strict; use warnings;
 
 package Rosetta::L::en;
-use version; our $VERSION = qv('0.19.0');
+use version; our $VERSION = qv('0.19.1');
 
 ######################################################################
 
@@ -146,7 +146,7 @@ Rosetta::L::en - Localization of Rosetta for English
 
 =head1 VERSION
 
-This document describes Rosetta::L::en version 0.19.0.
+This document describes Rosetta::L::en version 0.19.1.
 
 =head1 SYNOPSIS
 
@@ -175,15 +175,16 @@ This document describes Rosetta::L::en version 0.19.0.
 
 =head1 DESCRIPTION
 
-The Rosetta::L::en Perl 5 module contains localization data for Rosetta.  It is
-designed to be interpreted by Locale::KeyedText.  Besides localizing generic
-error messages that Rosetta produces itself, this file also provides a
-ready-made set of generic database error strings that can be thrown by any
-Rosetta Engine.
+The Rosetta::L::en Perl 5 module contains localization data for Rosetta. 
+It is designed to be interpreted by Locale::KeyedText.  Besides localizing
+generic error messages that Rosetta produces itself, this file also
+provides a ready-made set of generic database error strings that can be
+thrown by any Rosetta Engine.
 
-This class is optional and you can still use Rosetta effectively without it,
-especially if you plan to either show users different error messages than this
-class defines, or not show them anything because you are "handling it".
+This class is optional and you can still use Rosetta effectively without
+it, especially if you plan to either show users different error messages
+than this class defines, or not show them anything because you are
+"handling it".
 
 =head1 FUNCTIONS
 
@@ -191,19 +192,19 @@ class defines, or not show them anything because you are "handling it".
 
     my $user_text_template = Rosetta::L::en->get_text_by_key( 'foo' );
 
-This function takes a Message Key string in MSG_KEY and returns the associated
-user text template string, if there is one, or undef if not.
+This function takes a Message Key string in MSG_KEY and returns the
+associated user text template string, if there is one, or undef if not.
 
 =head1 DEPENDENCIES
 
 This module requires any version of Perl 5.x.y that is at least 5.8.1.
 
-It also requires the Perl module L<version>, which would
-conceptually be built-in to Perl, but isn't, so it is on CPAN instead.
+It also requires the Perl module L<version>, which would conceptually be
+built-in to Perl, but isn't, so it is on CPAN instead.
 
-This module has no enforced dependencies on L<Locale::KeyedText>, which is on 
-CPAN, or on L<Rosetta>, which is in the current distribution, 
-but it is designed to be used in conjunction with them.
+This module has no enforced dependencies on L<Locale::KeyedText>, which is
+on CPAN, or on L<Rosetta>, which is in the current distribution, but it is
+designed to be used in conjunction with them.
 
 =head1 INCOMPATIBILITIES
 
@@ -215,13 +216,13 @@ L<perl(1)>, L<Locale::KeyedText>, L<Rosetta>.
 
 =head1 BUGS AND LIMITATIONS
 
-The structure of this module is trivially simple and has no known bugs. 
+The structure of this module is trivially simple and has no known bugs.
 
 However, the locale data that this module contains may be subject to large
-changes in the future; you can determine the likeliness of this by examining the
-development status and/or BUGS AND LIMITATIONS documentation of the other module
-that this one is localizing; there tends to be a high correlation in the rate of 
-change between that module and this one.
+changes in the future; you can determine the likeliness of this by
+examining the development status and/or BUGS AND LIMITATIONS documentation
+of the other module that this one is localizing; there tends to be a high
+correlation in the rate of change between that module and this one.
 
 =head1 AUTHOR
 
@@ -232,35 +233,36 @@ Darren R. Duncan (C<perl@DarrenDuncan.net>)
 This file is part of the Rosetta database portability library.
 
 Rosetta is Copyright (c) 2002-2005, Darren R. Duncan.  All rights reserved.
-Address comments, suggestions, and bug reports to C<perl@DarrenDuncan.net>, or
-visit L<http://www.DarrenDuncan.net/> for more information.
+Address comments, suggestions, and bug reports to C<perl@DarrenDuncan.net>,
+or visit L<http://www.DarrenDuncan.net/> for more information.
 
-Rosetta is free software; you can redistribute it and/or modify it under the
-terms of the GNU General Public License (GPL) as published by the Free Software
-Foundation (L<http://www.fsf.org/>); either version 2 of the License, or (at your
-option) any later version.  You should have received a copy of the GPL as part
-of the Rosetta distribution, in the file named "GPL"; if not, write to the Free
-Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301,
-USA.
+Rosetta is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License (GPL) as published by the Free
+Software Foundation (L<http://www.fsf.org/>); either version 2 of the
+License, or (at your option) any later version.  You should have received a
+copy of the GPL as part of the Rosetta distribution, in the file named
+"GPL"; if not, write to the Free Software Foundation, Inc., 51 Franklin St,
+Fifth Floor, Boston, MA  02110-1301, USA.
 
 Linking Rosetta statically or dynamically with other modules is making a
 combined work based on Rosetta.  Thus, the terms and conditions of the GPL
-cover the whole combination.  As a special exception, the copyright holders of
-Rosetta give you permission to link Rosetta with independent modules,
-regardless of the license terms of these independent modules, and to copy and
-distribute the resulting combined work under terms of your choice, provided
-that every copy of the combined work is accompanied by a complete copy of the
-source code of Rosetta (the version of Rosetta used to produce the combined
-work), being distributed under the terms of the GPL plus this exception.  An
-independent module is a module which is not derived from or based on Rosetta,
-and which is fully useable when not linked to Rosetta in any form.
+cover the whole combination.  As a special exception, the copyright holders
+of Rosetta give you permission to link Rosetta with independent modules,
+regardless of the license terms of these independent modules, and to copy
+and distribute the resulting combined work under terms of your choice,
+provided that every copy of the combined work is accompanied by a complete
+copy of the source code of Rosetta (the version of Rosetta used to produce
+the combined work), being distributed under the terms of the GPL plus this
+exception.  An independent module is a module which is not derived from or
+based on Rosetta, and which is fully useable when not linked to Rosetta in
+any form.
 
 Any versions of Rosetta that you modify and distribute must carry prominent
 notices stating that you changed the files and the date of any changes, in
 addition to preserving this original copyright notice and other credits.
 Rosetta is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE.
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE.
 
 While it is by no means required, the copyright holders of Rosetta would
 appreciate being informed any time you create a modified version of Rosetta
